pub struct Order {Show 15 fields
pub created_dt: String,
pub djstripe_checkout_session: Option<Box<DjStripeCheckoutSession>>,
pub djstripe_customer: Option<Box<DjStripeCustomer>>,
pub djstripe_payment_intent: Option<Box<DjStripePaymentIntent>>,
pub email: String,
pub id: String,
pub is_shippable: bool,
pub is_subscription: bool,
pub last_status: Box<OrderStatus>,
pub products: Vec<Product>,
pub status_history: Vec<OrderStatus>,
pub stripe_checkout_session_data: HashMap<String, Value>,
pub user: Option<Box<User>>,
pub receipt_url: Option<String>,
pub portal_url: Option<String>,
}Expand description
Order : Djstripe’s representation of Stripe Checkout model is missing a number of fields, like subtotal amount and shipping/tax charges stripe_checkout_session_data is the raw JSON returned by stripe.checkout.Session.retrieve
Fields
created_dt: Stringdjstripe_checkout_session: Option<Box<DjStripeCheckoutSession>>djstripe_customer: Option<Box<DjStripeCustomer>>djstripe_payment_intent: Option<Box<DjStripePaymentIntent>>email: Stringid: Stringis_shippable: boolis_subscription: boollast_status: Box<OrderStatus>products: Vec<Product>status_history: Vec<OrderStatus>stripe_checkout_session_data: HashMap<String, Value>user: Option<Box<User>>receipt_url: Option<String>portal_url: Option<String>Implementations
Sourceimpl Order
impl Order
Sourcepub fn new(
created_dt: String,
djstripe_checkout_session: Option<DjStripeCheckoutSession>,
djstripe_customer: Option<DjStripeCustomer>,
djstripe_payment_intent: Option<DjStripePaymentIntent>,
email: String,
id: String,
is_shippable: bool,
is_subscription: bool,
last_status: OrderStatus,
products: Vec<Product>,
status_history: Vec<OrderStatus>,
stripe_checkout_session_data: HashMap<String, Value>,
receipt_url: Option<String>,
portal_url: Option<String>,
) -> Order
pub fn new( created_dt: String, djstripe_checkout_session: Option<DjStripeCheckoutSession>, djstripe_customer: Option<DjStripeCustomer>, djstripe_payment_intent: Option<DjStripePaymentIntent>, email: String, id: String, is_shippable: bool, is_subscription: bool, last_status: OrderStatus, products: Vec<Product>, status_history: Vec<OrderStatus>, stripe_checkout_session_data: HashMap<String, Value>, receipt_url: Option<String>, portal_url: Option<String>, ) -> Order
Djstripe’s representation of Stripe Checkout model is missing a number of fields, like subtotal amount and shipping/tax charges stripe_checkout_session_data is the raw JSON returned by stripe.checkout.Session.retrieve